@@ -25,11 +25,13 @@ class JsonExporter(MetricExporter):
             if not metric:
                 continue
             if not dic.get(metric.name):
-                dic[metric.name] = [{"value": metric.collect(),
+                dic[metric.name] = [{"kind": metric.kind,
+                                     "value": metric.collect(),
                                      "labels": metric.labels,
                                      "timestamp": metric.timestamp}]
             else:
-                dic[metric.name].append({"value": metric.collect(),
+                dic[metric.name].append({"kind": metric.kind,
+                                         "value": metric.collect(),
                                          "labels": metric.labels,
                                          "timestamp": metric.timestamp})
         return dic
