@@ -200,6 +200,8 @@ class App(Generic[GenericDependencyContainer]):
         asyncio.run(self._dispatch_stage(AppStage.BEFORE_SERVER_START))
         sanic_conf = self.container.app_config().sanic
         start_args = sanic_conf.dict() if sanic_conf else {}
+        if settings.DEBUG:
+            start_args["debug"] = True
         self.sanic.run(**start_args)
 
 
