@@ -9,6 +9,7 @@ from web_foundation.extentions.addons.addon_loader import AddonsLoader
 from web_foundation.kernel.dependency import Dependency
 from web_foundation.kernel.messaging.channel import IChannel
 from web_foundation.kernel.service import Service
+from web_foundation.kernel.stage import ListenerRegistrator
 from web_foundation.resources.files.interface import FilesResource
 from web_foundation.resources.resource import Resource
 from web_foundation.resources.stores.interface import DataStore
@@ -35,8 +36,13 @@ class DependencyContainer:
             yield resource
 
     async def before_app_run(self):
-        for resource in self.resources:
-            await resource.before_app_run(self.app_config())
+        pass
+
+    def set_listeners(self, registrator: ListenerRegistrator):
+        for dep, name in in_obj_classes(self, Dependency):
+            if inited := dep():
+                if hasattr(inited, "set_listeners"):
+                    inited.set_listeners(registrator)
 
     async def init_resources(self, channel: IChannel | None = None):
         for resource in self.resources:
@@ -49,5 +55,4 @@ class DependencyContainer:
     def services(self):
         return set(in_obj_subclasses(self, Service))
 
-
 GenericDependencyContainer = TypeVar("GenericDependencyContainer", bound=DependencyContainer)
